"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const moment = require("moment");
const external_task_state_1 = require("./external_task_state");
/**
 * Describes an ExternalTask that the ProcessEngine has delegated to an
 * ExternalTask worker for processing.
 */
class ExternalTask {
    constructor() {
        this.state = external_task_state_1.ExternalTaskState.pending;
    }
    /**
     * Determines whether the ExternalTask is currently locked or not.
     * A finished ExternalTask is always locked.
     */
    get isLocked() {
        if (!this.lockExpirationTime) {
            return false;
        }
        const lockExpirationAsMoment = moment(this.lockExpirationTime);
        const now = moment();
        return lockExpirationAsMoment.isAfter(now);
    }
}
exports.ExternalTask = ExternalTask;
//# sourceMappingURL=external_task.js.map